"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = __importStar(require("path"));
const gitDiffScraper_1 = require("./gitDiffScraper");
const commons_1 = require("@git-temporal/commons");
const gitRoot = commons_1.findGitRoot('.');
const testFile = path.join(gitRoot, 'package.json');
const firstRootCommitHashes = getFirstCommitHashes(gitRoot);
const firstFileCommitHashes = getFirstCommitHashes(testFile);
console.log('firstRootCommitHashes', firstRootCommitHashes);
console.log('firstFileCommitHashes', firstFileCommitHashes);
describe('git-diff-scraper', () => {
    it('should return a directory when path is a directory', () => {
        const diff = gitDiffScraper_1.getDiff(gitRoot);
        expect(diff.isDirectory).toEqual(true);
    });
    it('should return a file when path is a file', () => {
        const diff = gitDiffScraper_1.getDiff(testFile);
        expect(diff.isDirectory).toEqual(false);
    });
    it('should return HEAD and local changes when commits are null', () => {
        const diff = gitDiffScraper_1.getDiff(gitRoot);
        expect(diff.leftCommit).toEqual('HEAD');
        expect(diff.rightCommit).toEqual('local');
    });
    it('should return directory differences for two commits', () => {
        const diff = gitDiffScraper_1.getDiff(gitRoot, firstRootCommitHashes[1], firstRootCommitHashes[8]);
        expect(diff).toMatchSnapshot();
        expect(diff.isDirectory).toEqual(true);
        expect(diff.leftFileContents).toBeFalsy();
        expect(diff.leftFileContents).toBeFalsy();
        expect(diff.modifiedFiles.length).toBeGreaterThan(0);
    });
    it('should return file differences for two commits', () => {
        const diff = gitDiffScraper_1.getDiff(testFile, firstFileCommitHashes[1], firstFileCommitHashes[8]);
        expect(diff).toMatchSnapshot();
        expect(diff.isDirectory).toEqual(false);
        expect(diff.leftFileContents).toBeTruthy();
        expect(diff.leftFileContents).toBeTruthy();
        expect(diff.modifiedFiles.length).toBeFalsy();
    });
});
function getFirstCommitHashes(dir) {
    return commons_1.execSync(`git log --pretty="format:%H" --topo-order --date=local ${dir}`)
        .split(/(\n|\r\n)/)
        .slice(-10)
        .reverse();
}
